%global major 2.0
%global minor 1

Name:		jaxodraw
Version:	%{major}.%{minor}
Release:	4%{?dist}
Summary:	A Java program for drawing Feynman diagrams
Group:		Applications/Engineering 
License:	GPLv2+
URL:		http://jaxodraw.sourceforge.net/
Source0:	http://downloads.sourceforge.net/%{name}/%{name}-%{major}-%{minor}_src.tar.gz
# LaTeX file for exporting figures
Source1:	http://downloads.sourceforge.net/%{name}/axodraw4j_2008_11_19.tar.gz
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildArch:	noarch

BuildRequires:	ant
BuildRequires:	desktop-file-utils
# java-devel, we need at least 1.6.0
BuildRequires:	java-devel >= 1:1.6.0
BuildRequires:	jpackage-utils
# Unit testing capabilities
BuildRequires:	ant-junit

Requires:	java >= 1:1.6.0
Requires:	jpackage-utils

%description
JaxoDraw is a Java program for drawing Feynman diagrams. It has a complete
graphical user interface that allows to carry out all actions in a mouse
click-and-drag fashion. Fine-tuning of the diagrams is also possible through
keyboard entries. Graphs may be exported to (encapsulated) postscript and can
be saved in XML files to be used in later sessions.

%package javadoc
Summary:        Javadocs for %{name}
Group:          Documentation
Requires:       %{name} = %{version}-%{release}
Requires:       jpackage-utils

%description javadoc
This package contains the API documentation for %{name}.


%package latex
Summary:	LaTeX style file axodraw4j.sty for documents generated with jaxodraw
Group:		Applications/Engineering
License:	LPPL
# In order to compile documents one needs a LaTeX compiler
Requires:	tex(latex)

%description latex
This package contains the LaTeX style file that is needed for EPS export
functionality in jaxodraw.

You need this if you want the export to EPS function to work or if you want to
compile LaTeX files generated with jaxodraw.

%prep
%setup -q -n JaxoDraw-%{major}-%{minor} -a 1
find -name '*.jar' -o -name '*.class' -exec rm -f '{}' \;

# Convert documentation encoding
for file in src/doc/{TODO,CHANGELOG,README,BUGS} src/doc/legal/{GNU-,}LICENSE; do
 sed 's/\r//' $file > $file.new && \
 touch -r $file $file.new && \
 mv $file.new $file
done

# Desktop file
cat >> %{name}.desktop << EOF
[Desktop Entry]
Name=JaxoDraw
Comment=Tool for drawing Feynman diagrams
Exec=%{name}
Terminal=false
Type=Application
Categories=Graphics;2DGraphics;VectorGraphics;Physics;Science;
EOF

# Invocation script
cat >> %{name} << EOF
#!/bin/sh
java -jar %{_javadir}/%{name}.jar
EOF

%build
ant jar javadoc

%install
rm -rf %{buildroot}
install -D -p -m 644 build/%{name}-%{major}-%{minor}.jar %{buildroot}%{_javadir}/%{name}.jar
install -D -p -m 755 %{name} %{buildroot}%{_bindir}/%{name}
desktop-file-install --dir=%{buildroot}%{_datadir}/applications %{name}.desktop

# Javadoc
mkdir -p %{buildroot}%{_javadocdir}/%{name}
cp -rp build/javadoc/* %{buildroot}%{_javadocdir}/%{name}

# LaTeX style
install -D -p -m 644 axodraw4j.sty %{buildroot}%{_datadir}/texmf/tex/latex/axodraw4j/axodraw4j.sty

%check
# Unit tests fail with Open JDK
#ant test

%clean
rm -rf %{buildroot}

%post latex -p /usr/bin/texhash
%postun latex -p /usr/bin/texhash

%files
%defattr(-,root,root,-)
%doc src/doc/* axodraw4j-summary.txt
%{_bindir}/%{name}
%{_javadir}/%{name}.jar
%{_datadir}/applications/%{name}.desktop

%files javadoc
%defattr(-,root,root,-)
%{_javadocdir}/%{name}/

%files latex
%defattr(-,root,root,-)
%{_datadir}/texmf/tex/latex/axodraw4j/

%changelog
* Mon Nov 30 2009 Jussi Lehtola <jussilehtola@fedoraproject.org> - 2.0.1-4
- Get rid of erroneous Require.

* Fri Oct 23 2009 Jussi Lehtola <jussilehtola@fedoraproject.org> - 2.0.1-3
- Build and include javadoc.
- Add infrastructure for unit testing.

* Wed Oct 21 2009 Jussi Lehtola <jussilehtola@fedoraproject.org> - 2.0.1-2
- Generalize requires on latex package from texlive-foo to tex(foo).

* Wed Aug 05 2009 Jussi Lehtola <jussilehtola@fedoraproject.org> - 2.0.1-1
- Rebase to upstream 2.0-1 which removes the unused license file.

* Wed Jul 29 2009 Jussi Lehtola <jussilehtola@fedoraproject.org> - 2.0-3
- Branch stylefile into its own package to make licenses clearer.

* Wed Jun 10 2009 Jussi Lehtola <jussilehtola@fedoraproject.org> - 2.0-2
- Changed license to GPLv2+ (jaxodraw) and LPPL (axodraw4j.sty).

* Sat Jun 06 2009 Jussi Lehtola <jussilehtola@fedoraproject.org> - 2.0-1
- First release.
